@@ -106,7 +106,7 @@ void QueueView::setNowPlaying(QList<Spotify::Track*> queue, int currQueuePos, bo
 {
         //set the view into play queue (now playing mode), displaying the current play queue
 
-            m_PlayQueue = queue;
+           m_PlayQueue = queue;
 
             m_pCurrTrack = m_PlayQueue.at(currQueuePos);
 
@@ -160,16 +160,7 @@ void QueueView::loadTrackData(Spotify::Track* track)
         }
         if(track->getAlbum())
         {
-
-            if(!track->getAlbum()->getImage().isNull()) //album cover already loaded
-            {
-                m_AlbumCoverContainer.setPixmap(QPixmap::fromImage(track->getAlbum()->getImage()));
-            }
-            else
-            {
-                 m_pSession->getAlbumCover(track->getAlbum()); //request to load album coverart
-            }
-
+            m_pSession->getAlbumCover(track->getAlbum()); //request to load album coverart
         }
 
         m_currTrackDuration = track->getDuration().hour()*3600+track->getDuration().minute()*60+track->getDuration().second(); //current track duration (in secs)
@@ -237,8 +228,12 @@ void QueueView::OnTrackActivated(QListWidgetItem *currTrack)
     {
         m_currQueuePos = m_TrackInfo.currentRow();
 
+        qDebug() << "OnTrackActivated pos : " << m_currQueuePos;
+
         m_pCurrTrack = m_PlayQueue.at(m_currQueuePos);
 
+        qDebug() << "Track pointer:"  << m_pCurrTrack;
+
         if(m_pCurrTrack) //we have got a valid track instance
         {
             loadTrackData(m_pCurrTrack);
@@ -390,6 +385,7 @@ void QueueView::OnTrackPlaybackFinished()
         m_currQueuePos++;
         qDebug()<< "New queue pos: " << m_currQueuePos;
         m_pCurrTrack = m_PlayQueue.at(m_currQueuePos);
+        qDebug() << "Track pointer:"  << m_pCurrTrack;
         if(m_pCurrTrack)
         {
             m_pProgressSlider->setPos1(0);
