@@ -13,6 +13,7 @@
 #include <QtGui/QListWidget>
 #include <QtGui/QListWidgetItem>
 #include <QDebug>
+#include <QScrollBar>
 #include <QTextStream>
 #include <QtGui/QPixmap>
 #include <QMaemo5InformationBox>
@@ -35,10 +36,12 @@ private:
 
     QWidget m_MainLayout;
 
+    QWidget m_BottomArea;
+
     QGridLayout m_GridLayout;
 
     QVBoxLayout m_AlbumLayout;
-    QHBoxLayout m_PlayControls;
+    QGridLayout m_PlayControls;
 
     QLabel m_AlbumCoverContainer;
 
@@ -56,8 +59,6 @@ private:
 
     SpectrumAnalyzer* m_pSpectrum; //spectrum (active during audio playback)
 
-    QLabel m_CurrTrackPosLabel; //displays the current track playback position / total track duration
-
     QListWidget m_TrackInfo;
 
     Spotify::Session* m_pSession; //Spotify session instance
