@@ -15,12 +15,14 @@
 #include <QtGui/QPushButton>
 #include <QtGui/QCloseEvent>
 #include <QSettings>
+#include <QFont>
 #include <QtMaemo5/QMaemo5InformationBox>
 #include <qspotify_src/spotifysession.h>
 #include "logindialog.h"
 #include "TrackView.h"
 #include "QueueView.h"
 #include "SpectrumAnalyzer.h"
+#include "customlabel.h"
 
 class MainWindow : public QMainWindow
 {
@@ -33,12 +35,8 @@ public:
 
 private:
 
-    bool m_bLoggedIn; //member set to true when succesfully logged-in to Spotify service
-
     QSettings* m_pAppSettings; //application settings instance
 
-    SpectrumAnalyzer* m_pSpectrum; //spectrum analyzer widget
-
     QWidget m_MainLayout;
 
     QGridLayout m_GridLayout;
@@ -53,14 +51,22 @@ private:
 
     QPushButton m_SearchBtn;
 
-    QLabel m_SearchCaption;
-
     QLineEdit m_SearchInput;
 
-    QLabel m_PlaylistsCaption;
-
     QListWidget m_PlaylistInfo;
 
+    CustomLabel m_NowPlayingIcon;
+
+    QFont m_NowPlayingFont;
+
+    CustomLabel m_NowPlayingInfo;
+
+    CustomLabel m_NowPlayingPositionInfo;
+
+    QString m_strNowPlayingInfo;
+
+    SpectrumAnalyzer* m_pSpectrum; //spectrum analyzer widget
+
     QList<Spotify::Playlist*> m_Playlists; //list holding pointers to playlist instances
 
     QList<Spotify::Track*> m_PlayQueue; //current playqueue
@@ -68,10 +74,10 @@ private:
     qint32 m_currQueuePos; //current playqueue position
 
     bool m_playing; //TRUE if in playing mode
-	
-	qint64 m_currPlaybackPos; //playback position for currently playing track
-	
-	qint64 m_currBuffPos; //buffering position for currently playing track
+
+    qint64 m_currPlaybackPos; //playback position for currently playing track
+
+    qint64 m_currBuffPos; //buffering position for currently playing track
 
     void logout(); //logout current user and display the login dialog
 
@@ -90,8 +96,9 @@ private slots:
      void OnNowPlaying();
      void OnSearch();
      void OnSearchComplete(Spotify::Search* search);
-	void OnTrackPosUpdated(qint64 pos);
-    void OnPlaybackPositionUpdated(qint64 pos);
+     void OnTrackPosUpdated(qint64 pos);
+     void OnPlaybackPositionUpdated(qint64 pos);
+     void OnPlaybackTokenLost();
 
 signals:
 
